use std::sync::Arc;
use ash::prelude::VkResult;
use ash::vk;
use crate::renderer::vulkan::VkDevice;

pub struct VkBuffer {
    device: Arc<VkDevice>,

    handle: vk::Buffer,
}

impl VkBuffer {
    pub fn new(device: &Arc<VkDevice>, info: &vk::BufferCreateInfo) -> VkResult<Self> {
        let buffer = unsafe { device.handle.create_buffer(info, None)? };

        Ok(VkBuffer { device: Arc::clone(device), handle: buffer })
    }


    pub fn mem_requirements(&self) -> vk::MemoryRequirements {
        unsafe { self.device.handle.get_buffer_memory_requirements(self.handle) }
    }
}

impl Drop for VkBuffer {
    fn drop(&mut self) {
        unsafe {
            self.device.handle.destroy_buffer(self.handle, None);
        }
    }
}