use std::sync::Arc;
use ash::prelude::VkResult;
use ash::vk;
use crate::renderer::vulkan::{Vertex, VkBuffer, VkDevice};

#[derive(Default)]
struct VertexScene {
    vertices: Vec<Vertex>,

    vertices_buffer: Option<VkBuffer>,
}

impl VertexScene {
    pub fn new() -> Self {
        let vertices = vec![
            Vertex::new([0.0, -0.5], [1.0, 0.0, 0.0]),
            Vertex::new([0.5, 0.5], [0.0, 1.0, 0.0]),
            Vertex::new([-0.5, 0.5], [0.0, 0.0, 1.0]),
        ];

        Self {
            vertices,
            ..Default::default()
        }
    }


    fn create_buffer(&mut self, device: &Arc<VkDevice>) -> VkResult<()> {
        let buffer_info = vk::BufferCreateInfo::default()
            .usage(vk::BufferUsageFlags::VERTEX_BUFFER)
            .sharing_mode(vk::SharingMode::EXCLUSIVE)
            .size(self.vertices.len() as u64 * size_of::<Vertex>() as u64);

        let buffer = VkBuffer::new(device, &buffer_info)?;
        self.vertices_buffer = Some(buffer);

        Ok(())
    }
}